==> sghi_core-0.2.30.tar.gz: lib/afya_moja_core/src/app_strings.dart <==
// Community strings
const String groupText = 'Group';

const String phoneNumberRequiredText = 'Phone number is required';
const String validPhoneNumberText = 'Please enter a valid phone number';

// Search
const String searchUser = 'Search user';

//User Details Card
const String correctionRequestString = 'Request for correction';
const String inviteToMyAfyaHubString = 'Invite to My Afya Hub';
const String viewProfileString = 'View profile';

//Custom confirm dialog
const String confirmString = 'Confirm';
const String cancelString = 'Cancel';
// Community Chat
const String awaitingModerationString = 'Awaiting Moderation';
const String typeYourMessageHereString = 'Type your Message here';
const String comingSoonText = 'Coming soon';

// Expansion Question
const String dateLabelText = 'Tap to select a date';

// error strings
const String slowInternet =
    'Looks like you have a slow internet connection. Please check your '
    'connection and try again';
const String userWithThatPhoneExists =
    'Sorry, a user with that phone number already exists, kindly log in '
    'to continue';
const String userWithThatEmailExists =
    'Sorry, a user with that email address already exists';
const String usernameExists = 'Sorry, that username already exists.';
const String userNotFound =
    'Sorry, we could not find a user with those details. Please confirm that '
    'the credentials you provided are correct';
const String wrongLoginCredentials = 'Your phone number or PIN do not match.';
const String pinNotFound = 'No PIN found for this user.';
const String pinExpired = 'Your PIN has expired';
const String pendingPINResetRequest = 'You have a pending PIN reset request';

const String defaultUserFriendlyMessage =
    'Sorry, an unknown error occurred, please try again or get help from our '
    'help center.';

/// Date picker format
const String datePickerFormat = 'dd MMM, yyyy';
const String retryString = 'Retry';

// create PIN
const String createNewPINSubTitleString = 'Enter your new 4 digit PIN.';
const String pinString = 'PIN';
const String confirmPinString = 'Confirm new PIN';
const String saveAndContinueButtonText = 'Save & Continue';
const String pinMustMatchString = 'PIN must match';

//login error widget
const String tooManyAttemptsString = 'Too many login attempts';
const String tooManyAttemptsMessageString =
    'You have made too many login attempts. No worries though, you can try again in ';
const String requestForAssistanceMessageString =
    'You can also request for assistance from your doctor or admin by tapping on the button below';

// Communities
const String moderatorText = 'Moderator';
const String bannedString = 'Banned';
const String promoteToModeratorText = 'Promote to moderator';
const String demoteUserText = 'Demote to normal user';
const String banUserText = 'Ban user';
const String unBanUserText = 'UnBan user';
const String actionsText = 'Actions';
const String removeFromGroupText = 'Remove user from group';
const String staffMemberText = 'Staff member';

//content
const String newText = 'New';
const String pdfText = 'PDF';
const String datePublishedString = 'Published on ';

const String newNotificationMessageString = 'Please check your notification inbox';
const String newNotificationTitleString = 'You have a new notification';

==> sghi_core-0.2.51.tar.gz: lib/afya_moja_core/src/app_strings.dart <==
// Community strings
const String groupText = 'Group';

const String phoneNumberRequiredText = 'Phone number is required';
const String validPhoneNumberText = 'Please enter a valid phone number';

// Search
const String searchUser = 'Search user';

//User Details Card
const String correctionRequestString = 'Request for correction';
const String inviteToMyAfyaHubString = 'Invite to My Afya Hub';
const String viewProfileString = 'View profile';

//Custom confirm dialog
const String confirmString = 'Confirm';
const String cancelString = 'Cancel';
// Community Chat
const String awaitingModerationString = 'Awaiting Moderation';
const String typeYourMessageHereString = 'Type your Message here';
const String comingSoonText = 'Coming soon';

// Expansion Question
const String dateLabelText = 'Tap to select a date';

// error strings
const String slowInternet =
    'Looks like you have a slow internet connection. Please check your '
    'connection and try again';
const String userWithThatPhoneExists =
    'Sorry, a user with that phone number already exists, kindly log in '
    'to continue';
const String userWithThatEmailExists =
    'Sorry, a user with that email address already exists';
const String usernameExists = 'Sorry, that username already exists.';
const String userNotFound =
    'Sorry, we could not find a user with those details. Please confirm that '
    'the credentials you provided are correct';
const String wrongLoginCredentials = 'Your username or PIN do not match.';
const String pinNotFound = 'No PIN found for this user.';
const String pinExpired = 'Your PIN has expired';
const String pendingPINResetRequest = 'You have a pending PIN reset request';

const String defaultUserFriendlyMessage =
    'Sorry, an unknown error occurred, please try again or get help from our '
    'help center.';

/// Date picker format
const String datePickerFormat = 'dd MMM, yyyy';
const String retryString = 'Retry';

// create PIN
const String createNewPINSubTitleString = 'Enter your new 4 digit PIN.';
const String pinString = 'PIN';
const String confirmPinString = 'Confirm new PIN';
const String saveAndContinueButtonText = 'Save & Continue';
const String pinMustMatchString = 'PIN must match';

//login error widget
const String tooManyAttemptsString = 'Too many login attempts';
const String tooManyAttemptsMessageString =
    'You have made too many login attempts. No worries though, you can try again in ';
const String requestForAssistanceMessageString =
    'You can also request for assistance from your doctor or admin by tapping on the button below';

// Communities
const String moderatorText = 'Moderator';
const String bannedString = 'Banned';
const String promoteToModeratorText = 'Promote to moderator';
const String demoteUserText = 'Demote to normal user';
const String banUserText = 'Ban user';
const String unBanUserText = 'UnBan user';
const String actionsText = 'Actions';
const String removeFromGroupText = 'Remove user from group';
const String staffMemberText = 'Staff member';

//content
const String newText = 'New';
const String pdfText = 'PDF';
const String datePublishedString = 'Published on ';

const String newNotificationMessageString = 'Please check your notification inbox';
const String newNotificationTitleString = 'You have a new notification';
